@@ -35,13 +35,10 @@ if [ $BUILD_RES -ne 0 ]; then
     exit $BUILD_RES
 fi
 
+# Only call exit on failures so we can source this script
 if [ x"$KRB5_VER" = "xheimdal" ] || [ "$OS_NAME" = "windows" ]; then
     # heimdal/Windows can't run the tests yet, so just make sure it imports and exit
-    python -c "import gssapi"
-    exit $?
+    python -c "import gssapi" || exit $?
+else
+    python setup.py nosetests --verbosity=3 || exit $?
 fi
-
-python setup.py nosetests --verbosity=3
-TEST_RES=$?
-
-exit $TEST_RES
